from setuptools import setup, find_packages

setup(
    name="labeldb",
    version="0.0.1",
    description="LabelDB",
    packages=["labeldb"],
    author="Activeloop",
    author_email="support@activeloop.ai",
    url="https://activeloop.ai",
)
